@@ -61,9 +61,6 @@ def print_help():
       type_strains     -> Compare GTDB to type strain of species designations at NCBI, LPSN, DSMZ, and/or StrainInfo
       type_species     -> Compare GTDB to type species of genus designations at NCBI, LPSN, DSMZ, and/or StrainInfo
 
-    Taxonomy finalization:
-      backfill -> Fill in missing rank information and finalize species names
-
     Species comparison:
       ncbi_species      -> Report differences between GTDB and NCBI species names
       gtdb_cluster_ncbi -> Report NCBI species within each GTDB-defined cluster
@@ -379,31 +376,6 @@ def main():
     type_species_parser.add_argument('--prefix', help="prefix for all output files", default='gvtk')
     type_species_parser.add_argument('--silent', help="suppress output", action='store_true')
 
-    # check type species
-    backfill_parser = subparsers.add_parser('backfill',
-                                            formatter_class=CustomHelpFormatter,
-                                            description='Fill in missing rank information.')
-    backfill_parser.add_argument('input_taxonomy', help='input taxonomy file to backfill')
-    backfill_parser.add_argument('prev_taxonomy', help='taxonomy file for previous GTDB release')
-    backfill_parser.add_argument('gtdb_metadata_file', help='file specifying GTDB metadata (TSV)')
-    backfill_parser.add_argument('gtdb_named_type_genomes',
-                                 help='file explicitly indicating type genomes for named species (gtdb_type_genomes_final.tsv from select_type_genomes)')
-    backfill_parser.add_argument('gtdb_synonym_file', help='file specifying GTDB declared synonyms')
-    backfill_parser.add_argument('sp_classification_ledger',
-                                 help='file indicating desired species names for specific genomes')
-    backfill_parser.add_argument('sp_placeholder_ledger',
-                                 help='file indicating desired species placeholder names for specific genomes')
-    backfill_parser.add_argument('genus_classification_ledger',
-                                 help='file indicating desired genus names for specific genomes')
-    backfill_parser.add_argument('user_genome_id_table',
-                                 help='table specifying mapping between GTDB user, UBA, and GenBank IDs (TSV)')
-    backfill_parser.add_argument('output_dir', help='output directory')
-    backfill_parser.add_argument('--curation_tree_file', help='tree to modify for curating backfilling')
-    backfill_parser.add_argument('--sp_cluster_file',
-                                 help="file indicating species cluster to use instead of GTDB metadata")
-    backfill_parser.add_argument('--prefix', help="prefix for all output files", default='gvtk')
-    backfill_parser.add_argument('--silent', help="suppress output", action='store_true')
-
     # compare NCBI and GTDB species names
     ncbi_species_parser = subparsers.add_parser('ncbi_species',
                                                 formatter_class=CustomHelpFormatter,
