@@ -33,7 +33,6 @@ from biolib.newick import parse_label
 
 from gtdb_validation_tk.common import read_gtdb_metadata, canonical_species_name, canonical_wgs_id
 from gtdb_validation_tk.check_taxonomy_file import CheckTaxonomyFile
-from gtdb_validation_tk.backfill import Backfill
 from gtdb_validation_tk.suffix_table import SuffixTable
 from gtdb_validation_tk.red_check import RED_Check
 from gtdb_validation_tk.missing_genera import MissingGenera
@@ -673,49 +672,6 @@ class OptionsParser(object):
 
         fout.close()
 
-    def backfill(self, options):
-        """Fill in missing rank information."""
-
-        check_file_exists(options.input_taxonomy)
-        check_file_exists(options.prev_taxonomy)
-        check_file_exists(options.gtdb_metadata_file)
-        check_file_exists(options.gtdb_named_type_genomes)
-        check_file_exists(options.gtdb_synonym_file)
-        check_file_exists(options.sp_classification_ledger)
-        check_file_exists(options.user_genome_id_table)
-        make_sure_path_exists(options.output_dir)
-
-        b = Backfill(options.prefix, options.output_dir)
-        output_taxonomy = b.run(options.input_taxonomy,
-                                options.prev_taxonomy,
-                                options.gtdb_metadata_file,
-                                options.gtdb_named_type_genomes,
-                                options.gtdb_synonym_file,
-                                options.sp_classification_ledger,
-                                options.sp_placeholder_ledger,
-                                options.genus_classification_ledger,
-                                options.user_genome_id_table,
-                                options.sp_cluster_file,
-                                options.curation_tree_file)
-
-        v = ValidateTypeMaterial()
-        v.validate_type_strains(output_taxonomy,
-                                options.gtdb_metadata_file,
-                                options.gtdb_synonym_file,
-                                False,
-                                options.prefix,
-                                os.path.join(options.output_dir, 'validate_type_material'))
-
-        v.validate_type_species(output_taxonomy,
-                                options.gtdb_metadata_file,
-                                options.gtdb_synonym_file,
-                                options.genus_classification_ledger,
-                                False,
-                                options.prefix,
-                                os.path.join(options.output_dir, 'validate_type_material'))
-
-        self.logger.info('Done.')
-
     def ncbi_species(self, options):
         """Report differences between GTDB and NCBI species names."""
 
@@ -893,8 +849,6 @@ class OptionsParser(object):
             self.type_species(options)
         elif options.subparser_name == 'val_table':
             self.val_table(options)
-        elif options.subparser_name == 'backfill':
-            self.backfill(options)
         elif options.subparser_name == 'ncbi_species':
             self.ncbi_species(options)
         elif options.subparser_name == 'gtdb_cluster_ncbi':
