@@ -29,7 +29,7 @@ from biolib.taxonomy import Taxonomy
 import dendropy
 
 
-class TaxDiff():
+class TaxDiff(object):
     """Tabulate differences between two taxonomies.
 
     Every taxon label in the first taxonomy is classified
